==> PlayerAnimationLibFabric-1.1.0%2Bmc.1.21.8-sources.jar: com/zigythebird/playeranim/mixin/firstPerson/EntityRenderDispatcherMixin.java <==
package com.zigythebird.playeranim.mixin.firstPerson;

import com.llamalad7.mixinextras.sugar.Local;
import com.zigythebird.playeranim.accessors.IAnimatedPlayer;
import com.zigythebird.playeranim.accessors.IPlayerAnimationState;
import com.zigythebird.playeranimcore.api.firstPerson.FirstPersonMode;
import net.minecraft.class_10017;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_310;
import net.minecraft.class_4184;
import net.minecraft.class_4538;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_897;
import net.minecraft.class_898;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_898.class)
public class EntityRenderDispatcherMixin {
    @Inject(method = "render(Lnet/minecraft/world/entity/Entity;DDDFLcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;ILnet/minecraft/client/renderer/entity/EntityRenderer;)V", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/renderer/entity/EntityRenderDispatcher;render(Lnet/minecraft/client/renderer/entity/state/EntityRenderState;DDDLcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;ILnet/minecraft/client/renderer/entity/EntityRenderer;)V"))
    private <E extends class_1297, S extends class_10017> void isFirstPersonPass(E entity, double xOffset, double yOffset, double zOffset, float partialTick, class_4587 poseStack, class_4597 bufferSource, int packedLight, class_897<? super E, S> renderer, CallbackInfo ci, @Local S entityRenderState) {
        class_4184 camera = class_310.method_1551().field_1773.method_19418();
        if (entity == camera.method_19331() && camera.method_19331() instanceof IAnimatedPlayer player && player.playerAnimLib$getAnimManager().isActive()
                && player.playerAnimLib$getAnimManager().getFirstPersonMode() == FirstPersonMode.THIRD_PERSON_MODEL && !camera.method_19333()
                    && (!(camera.method_19331() instanceof class_1309) || !((class_1309)camera.method_19331()).method_6113())) {
                ((IPlayerAnimationState) entityRenderState).playerAnimLib$setFirstPersonPass(true);
        }
    }

    @Inject(method = "renderShadow", at = @At("HEAD"), cancellable = true)
    private static void renderShadow_HEAD_PlayerAnimator(class_4587 poseStack, class_4597 bufferSource, class_10017 renderState, float strength, class_4538 level, float size, CallbackInfo ci) {
        if (renderState instanceof IPlayerAnimationState state && state.playerAnimLib$isFirstPersonPass()) {
            // Shadow doesn't render in first person,
            // so we don't want to make it appear during first person animation
            ci.cancel();
        }
    }
}

==> PlayerAnimationLibFabric-1.1.1%2Bmc.1.21.8-sources.jar: com/zigythebird/playeranim/mixin/firstPerson/EntityRenderDispatcherMixin.java <==
package com.zigythebird.playeranim.mixin.firstPerson;

import com.llamalad7.mixinextras.sugar.Local;
import com.zigythebird.playeranim.accessors.IAnimatedPlayer;
import com.zigythebird.playeranim.accessors.IPlayerAnimationState;
import com.zigythebird.playeranimcore.api.firstPerson.FirstPersonMode;
import net.minecraft.class_10017;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_310;
import net.minecraft.class_4184;
import net.minecraft.class_4538;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_897;
import net.minecraft.class_898;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_898.class)
public class EntityRenderDispatcherMixin {
    @Inject(method = "render(Lnet/minecraft/world/entity/Entity;DDDFLcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;ILnet/minecraft/client/renderer/entity/EntityRenderer;)V", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/renderer/entity/EntityRenderDispatcher;render(Lnet/minecraft/client/renderer/entity/state/EntityRenderState;DDDLcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;ILnet/minecraft/client/renderer/entity/EntityRenderer;)V"))
    private <E extends class_1297, S extends class_10017> void isFirstPersonPass(E entity, double xOffset, double yOffset, double zOffset, float partialTick, class_4587 poseStack, class_4597 bufferSource, int packedLight, class_897<? super E, S> renderer, CallbackInfo ci, @Local S entityRenderState) {
        class_4184 camera = class_310.method_1551().field_1773.method_19418();
        if (entityRenderState instanceof IPlayerAnimationState playerAnimationState) {
            playerAnimationState.playerAnimLib$setFirstPersonPass(
                    entity == camera.method_19331() && camera.method_19331() instanceof IAnimatedPlayer player &&
                    player.playerAnimLib$getAnimManager().isActive()
                    && player.playerAnimLib$getAnimManager().getFirstPersonMode() == FirstPersonMode.THIRD_PERSON_MODEL
                    && !camera.method_19333()
                    && (!(camera.method_19331() instanceof class_1309) || !((class_1309) camera.method_19331()).method_6113()));
        }
    }

    @Inject(method = "renderShadow", at = @At("HEAD"), cancellable = true)
    private static void renderShadow_HEAD_PlayerAnimator(class_4587 poseStack, class_4597 bufferSource, class_10017 renderState, float strength, class_4538 level, float size, CallbackInfo ci) {
        if (renderState instanceof IPlayerAnimationState state && state.playerAnimLib$isFirstPersonPass()) {
            // Shadow doesn't render in first person,
            // so we don't want to make it appear during first person animation
            ci.cancel();
        }
    }
}
